Example applications of PyGaia
==============================

The `examples <https://github.com/agabrown/PyGaia/tree/master/examples>`_ folder contains notebooks which illustrate the application of the PyGaia tools.